@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: MIDI pitches for guitar chord voicings
 
-our $VERSION = '0.0303';
+our $VERSION = '0.0304';
 
 use strict;
 use warnings;
@@ -124,7 +124,7 @@ MIDI::Chord::Guitar - MIDI pitches for guitar chord voicings
 
 =head1 VERSION
 
-version 0.0303
+version 0.0304
 
 =head1 SYNOPSIS
 
@@ -165,7 +165,7 @@ of an C<E A D G B E> tuned guitar.
 
 Computed attribute available after construction.
 
-The known chord names in the key of C are as follows:
+The known chord names are as follows:
 
   '' (major)
   aug
@@ -220,14 +220,26 @@ If no B<chord_name> is given, C<major> is used.
 
 If no B<variation> is given, all transformed voicings are returned.
 
+For example, here are the open chord specs for each note in the key of
+C:
+
+  'C3', '', 0
+  'D3', '', 4
+  'E2', '', 3
+  'F2', '', 3
+  'G2', '', 2
+  'A2', '', 1
+  'B2', '', 1
+
 =head2 voicings
 
   $mcg->voicings($chord_name);
   $mcg->voicings($chord_name, $format);
 
-Return all the voicings of a given B<chord_name>.  The default
-B<format> is C<midinum> but can be given as C<ISO> or C<midi> to
-return named notes with octaves.
+Return all the voicings of a given B<chord_name> in the key of C.
+
+The default B<format> is C<midinum> but can be given as C<ISO> or
+C<midi> to return named notes with octaves.
 
 The order of the voicing variations of a chord is by fret position.
 So, the first variations are at lower frets.  Please use the above
